Object.defineProperty(exports, "__esModule", { value: true });

function moduleResolverByPaths(root, paths, extensions) {
    const { resolvePath } = require("babel-plugin-module-resolver");
    const matchers = createMatchers(paths);
    const options = {
        root,
        extensions,
        resolvePath(specifier, importer, options) {
            let path;
            for (let i = 0; !path && i < matchers.length; i++)
                path = tryMatcher(matchers[i], resolvePath, specifier, importer, options);
            return path || resolvePath(specifier, importer, options);
        },
    };
    return ["babel-plugin-module-resolver", options, "ts-config-paths-module-resolver"];
}
exports.moduleResolverByPaths = moduleResolverByPaths;

function tryMatcher(matcher, resolver, specifier, importer, options) {
    let path;
    const [regex, substitutions] = matcher;
    const [, value] = regex.exec(specifier) || [];
    if (value)
        for (let i = 0; !path && i < substitutions.length; i++) {
            specifier = substitutions[i].replace("*", value);
            path = resolver(specifier, importer, options);
        }
    return path;
}

function createMatchers(paths) {
    const matchers = [];
    for (const key of Object.keys(paths)) {
        const pattern = key.replace("*", "(.+)");
        const regex = new RegExp(pattern);
        const substitutions = paths[key].map(toSubstitution);
        matchers.push([regex, substitutions]);
    }
    return matchers;
}
function toSubstitution(value) {
    if (value.startsWith("."))
        value = value.slice(1);
    if (value.startsWith("/"))
        value = value.slice(1);
    return value;
}
//# sourceMappingURL=module-resolver.js.map
